@@ -99,7 +99,15 @@ columns_driver_status_set_properties (GtkTreeViewColumn *column,
         column_id = gtk_tree_view_column_get_sort_column_id (column);
         gtk_tree_model_get (model, iter, column_id, &status, -1);
 
-        if (strcmp (status, "imperfect") == 0)
+        /* XXX For the "good" icon I want some kind of positive symbol; a
+         *     checkmark or thumbs up or something.  The "emblem-default"
+         *     image in gnome-icon-theme seems to be the closest match at
+         *     this time (a green checkmark), but may not be suitable for
+         *     all icon themes. */
+
+        if (strcmp (status, "good") == 0)
+                pixbuf = columns_get_icon_name ("emblem-default");
+        else if (strcmp (status, "imperfect") == 0)
                 pixbuf = columns_get_icon_name ("dialog-warning");
         else if (strcmp (status, "preliminary") == 0)
                 pixbuf = columns_get_icon_name ("dialog-error");
